@@ -28,16 +28,16 @@
 
 #include <config.h>
 #include "screen-private.h"
-#include "util.h"
-#include "errors.h"
+#include <meta/util.h>
+#include <meta/errors.h>
 #include "window-private.h"
-#include "frame-private.h"
-#include "prefs.h"
+#include "frame.h"
+#include <meta/prefs.h>
 #include "workspace-private.h"
 #include "keybindings-private.h"
 #include "stack.h"
 #include "xprops.h"
-#include "compositor.h"
+#include <meta/compositor.h>
 #include "mutter-marshal.h"
 #include "mutter-enum-types.h"
 
@@ -84,8 +84,11 @@ enum
   WORKSPACE_ADDED,
   WORKSPACE_REMOVED,
   WORKSPACE_SWITCHED,
+  WINDOW_ENTERED_MONITOR,
+  WINDOW_LEFT_MONITOR,
   STARTUP_SEQUENCE_CHANGED,
   WORKAREAS_CHANGED,
+  MONITORS_CHANGED,
 
   LAST_SIGNAL
 };
@@ -200,6 +203,28 @@ meta_screen_class_init (MetaScreenClass *klass)
                   G_TYPE_INT,
                   MUTTER_TYPE_MOTION_DIRECTION);
 
+  screen_signals[WINDOW_ENTERED_MONITOR] =
+    g_signal_new ("window-entered-monitor",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL,
+                  _mutter_marshal_VOID__INT_OBJECT,
+                  G_TYPE_NONE, 2,
+                  G_TYPE_INT,
+                  META_TYPE_WINDOW);
+
+  screen_signals[WINDOW_LEFT_MONITOR] =
+    g_signal_new ("window-left-monitor",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL,
+                  _mutter_marshal_VOID__INT_OBJECT,
+                  G_TYPE_NONE, 2,
+                  G_TYPE_INT,
+                  META_TYPE_WINDOW);
+
   screen_signals[STARTUP_SEQUENCE_CHANGED] =
     g_signal_new ("startup-sequence-changed",
                   G_TYPE_FROM_CLASS (klass),
@@ -227,6 +252,15 @@ meta_screen_class_init (MetaScreenClass *klass)
                   g_cclosure_marshal_VOID__VOID,
                   G_TYPE_NONE, 0);
 
+  screen_signals[MONITORS_CHANGED] =
+    g_signal_new ("monitors-changed",
+		  G_TYPE_FROM_CLASS (object_class),
+		  G_SIGNAL_RUN_LAST,
+		  G_STRUCT_OFFSET (MetaScreenClass, monitors_changed),
+		  NULL, NULL,
+		  g_cclosure_marshal_VOID__VOID,
+		  G_TYPE_NONE, 0);
+
   g_object_class_install_property (object_class,
                                    PROP_N_WORKSPACES,
                                    pspec);
@@ -277,7 +311,7 @@ set_supported_hint (MetaScreen *screen)
   Atom atoms[] = {
 #define EWMH_ATOMS_ONLY
 #define item(x)  screen->display->atom_##x,
-#include "atomnames.h"
+#include <meta/atomnames.h>
 #undef item
 #undef EWMH_ATOMS_ONLY
   };
@@ -342,6 +376,18 @@ reload_monitor_infos (MetaScreen *screen)
   screen->n_monitor_infos = 0;
   screen->last_monitor_index = 0;
 
+  /* Xinerama doesn't have a concept of primary monitor, however XRandR
+   * does. However, the XRandR xinerama compat code always sorts the
+   * primary output first, so we rely on that here. We could use the
+   * native XRandR calls instead of xinerama, but that would be
+   * slightly problematic for _NET_WM_FULLSCREEN_MONITORS support, as
+   * that is defined in terms of xinerama monitor indexes.
+   * So, since we don't need anything in xrandr except the primary
+   * we can keep using xinerama and use the first monitor as the
+   * primary.
+   */
+  screen->primary_monitor_index = 0;
+
   screen->display->monitor_cache_invalidated = TRUE;
 
   if (g_getenv ("MUTTER_DEBUG_XINERAMA"))
@@ -2130,6 +2176,22 @@ meta_screen_get_n_monitors (MetaScreen *screen)
   return screen->n_monitor_infos;
 }
 
+/**
+ * meta_screen_get_primary_monitor:
+ * @screen: a #MetaScreen
+ *
+ * Gets the index of the primary monitor on this @screen.
+ *
+ * Return value: a monitor index
+ */
+int
+meta_screen_get_primary_monitor (MetaScreen *screen)
+{
+  g_return_val_if_fail (META_IS_SCREEN (screen), 0);
+
+  return screen->primary_monitor_index;
+}
+
 /**
  * meta_screen_get_monitor_geometry:
  * @screen: a #MetaScreen
@@ -2778,10 +2840,27 @@ void
 meta_screen_resize (MetaScreen *screen,
                     int         width,
                     int         height)
-{  
+{
+  GSList *windows, *tmp;
+
   screen->rect.width = width;
   screen->rect.height = height;
 
+  /* Clear monitor for all windows on this screen, as it will become
+   * invalid. */
+  windows = meta_display_list_windows (screen->display,
+                                       META_LIST_INCLUDE_OVERRIDE_REDIRECT);
+  for (tmp = windows; tmp != NULL; tmp = tmp->next)
+    {
+      MetaWindow *window = tmp->data;
+
+      if (window->screen == screen)
+        {
+          g_signal_emit_by_name (screen, "window-left-monitor", window->monitor->number, window);
+          window->monitor = NULL;
+        }
+    }
+
   reload_monitor_infos (screen);
   set_desktop_geometry_hint (screen);
   
@@ -2791,6 +2870,21 @@ meta_screen_resize (MetaScreen *screen,
 
   /* Queue a resize on all the windows */
   meta_screen_foreach_window (screen, meta_screen_resize_func, 0);
+
+  /* Fix up monitor for all windows on this screen */
+  windows = meta_display_list_windows (screen->display,
+                                       META_LIST_INCLUDE_OVERRIDE_REDIRECT);
+  for (tmp = windows; tmp != NULL; tmp = tmp->next)
+    {
+      MetaWindow *window = tmp->data;
+
+      if (window->screen == screen)
+        meta_window_update_monitor (window);
+    }
+
+  g_slist_free (windows);
+
+  g_signal_emit (screen, screen_signals[MONITORS_CHANGED], 0, index);
 }
 
 void
